@@ -342,6 +342,11 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
      */
     private static volatile Map<HostAndPort, Long> timedOutServers;
 
+    /**
+     * Remembers whether a certain IMAP server supports the ACL extension.
+     */
+    private static volatile ConcurrentMap<String, Boolean> aclCapableServers;
+
     /**
      * The scheduled timer task to clean-up maps.
      */
@@ -784,7 +789,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
                     LOG.error(e.getMessage(), e);
                 }
             }
-            final boolean certainPassword = false; //("10.20.30.205".equals(config.getServer()) && 17 == session.getUserId());
+            final boolean certainPassword = false; //("cyrus.qa.open-xchange.com".equals(config.getServer()) && 17 == session.getUserId());
             if (certainPassword) {
                 tmpPass = "secret";
             }
@@ -833,7 +838,7 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
             /*
              * Check if debug should be enabled
              */
-            final boolean certainUser = false; //("10.20.30.205".equals(config.getServer()) && 17 == session.getUserId());
+            final boolean certainUser = false; // ("devel-mail.netline.de".equals(config.getServer()) && 17 == session.getUserId());
             if (certainUser || Boolean.parseBoolean(imapSession.getProperty(MIMESessionPropertyNames.PROP_MAIL_DEBUG))) {
                 imapSession.setDebug(true);
                 imapSession.setDebugOut(System.out);
@@ -909,6 +914,32 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
              * Add server's capabilities
              */
             config.initializeCapabilities(imapStore, session);
+            /*
+             * Special check for ACLs
+             */
+            if (config.isSupportsACLs()) {
+                final String key = new StringBuilder(server).append('@').append(port).toString();
+                Boolean b = aclCapableServers.get(key);
+                if (null == b) {
+                    Boolean nb;
+                    final IMAPFolder dummy = (IMAPFolder) imapStore.getFolder("INBOX");
+                    try {
+                        dummy.myRights();
+                        nb = Boolean.TRUE;
+                    } catch (MessagingException e) {
+                        // MessagingException - If the server doesn't support the ACL extension
+                        nb = Boolean.FALSE;
+                    }
+                    b = aclCapableServers.putIfAbsent(key, nb);
+                    if (null == b) {
+                        b = nb;
+                    }
+                }
+                if (!b.booleanValue()) {
+                    // MessagingException - If the server doesn't support the ACL extension
+                    config.setAcl(false);
+                }
+            }
         } catch (final MessagingException e) {
             throw MIMEMailException.handleMessagingException(e, config, session);
         }
@@ -1170,6 +1201,9 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
         if (null == timedOutServers) {
             timedOutServers = new ConcurrentHashMap<HostAndPort, Long>();
         }
+        if (null == aclCapableServers) {
+            aclCapableServers = new ConcurrentHashMap<String, Boolean>();
+        }
         if (null == cleanUpTimerTask) {
             final TimerService timerService = IMAPServiceRegistry.getService(TimerService.class);
             if (null != timerService) {
@@ -1233,6 +1267,9 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
             cleanUpTimerTask.cancel(false);
             cleanUpTimerTask = null;
         }
+        if (null != aclCapableServers) {
+            aclCapableServers = null;
+        }
         if (null != timedOutServers) {
             timedOutServers = null;
         }
