@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -52,14 +52,17 @@ package com.openexchange.imap;
 import java.util.EnumMap;
 import java.util.Map;
 import com.openexchange.groupware.AbstractOXException;
+import com.openexchange.imap.cache.ListLsubCache;
 import com.openexchange.imap.config.IMAPConfig;
 import com.openexchange.mail.MailException;
+import com.openexchange.mail.dataobjects.MailFolder;
 import com.openexchange.mail.mime.MIMEMailException;
 import com.openexchange.session.Session;
+import com.sun.mail.imap.IMAPStore;
 
 /**
  * {@link IMAPException} - Indicates an IMAP error.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class IMAPException extends MIMEMailException {
@@ -180,6 +183,10 @@ public final class IMAPException extends MIMEMailException {
          * Update of folder %1$s failed
          */
         UPDATE_FAILED(IMAPCode.UPDATE_FAILED),
+        /**
+         * Rename of folder "%1$s" to "%2$s" failed with "%3$s".
+         */
+        RENAME_FAILED(IMAPCode.RENAME_FAILED),
         /**
          * Folder %1$s must not be deleted
          */
@@ -294,7 +301,7 @@ public final class IMAPException extends MIMEMailException {
          */
         CONNECT_ERROR(IMAPCode.CONNECT_ERROR),
         /**
-         * Mailbox' root folder must not be source or the destination fullname of a move operation.
+         * Mailbox' root folder must not be source or the destination full name of a move operation.
          */
         NO_ROOT_MOVE(IMAPCode.NO_ROOT_MOVE),
         /**
@@ -312,7 +319,30 @@ public final class IMAPException extends MIMEMailException {
         /**
          * A SQL error occurred: %1$s
          */
-        SQL_ERROR(IMAPCode.SQL_ERROR);
+        SQL_ERROR(IMAPCode.SQL_ERROR),
+        /**
+         * No rename access to mail folder %1$s
+         */
+        NO_RENAME_ACCESS(IMAPCode.NO_RENAME_ACCESS),
+        /**
+         * Unable to parse IMAP server URI "%1$s".
+         */
+        URI_PARSE_FAILED(IMAPCode.URI_PARSE_FAILED),
+        /**
+         * Default folder %1$s must not be unsubscribed.
+         */
+        NO_DEFAULT_FOLDER_UNSUBSCRIBE(IMAPCode.NO_DEFAULT_FOLDER_UNSUBSCRIBE),
+        /**
+         * IMAP server refuses to import one or more E-Mails.
+         */
+        INVALID_MESSAGE(IMAPCode.INVALID_MESSAGE),
+        /**
+         * Currently not possible to establish a new connection to server %1$s with login %2$s. Please try again.
+         */
+        CONNECTION_UNAVAILABLE(IMAPCode.CONNECTION_UNAVAILABLE),
+        
+
+        ;
 
         private final IMAPCode imapCode;
 
@@ -330,7 +360,7 @@ public final class IMAPException extends MIMEMailException {
 
     }
 
-    private static enum IMAPCode {
+    public static enum IMAPCode {
 
         /**
          * Missing parameter in mail connection: %1$s
@@ -483,11 +513,11 @@ public final class IMAPException extends MIMEMailException {
         /**
          * Default folder %1$s must not be updated
          */
-        NO_DEFAULT_FOLDER_UPDATE("Default folder %1$s cannot be updated", Category.PERMISSION, 2018),
+        NO_DEFAULT_FOLDER_UPDATE("Default folder %1$s must not be updated", Category.PERMISSION, 2018),
         /**
          * Default folder %1$s must not be updated on server %2$s with login %3$s (user=%4$s, context=%5$s)
          */
-        NO_DEFAULT_FOLDER_UPDATE_EXT("Default folder %1$s cannot be updated on server %2$s with login %3$s (user=%4$s, context=%5$s)", NO_DEFAULT_FOLDER_UPDATE),
+        NO_DEFAULT_FOLDER_UPDATE_EXT("Default folder %1$s must not be updated on server %2$s with login %3$s (user=%4$s, context=%5$s)", NO_DEFAULT_FOLDER_UPDATE),
         /**
          * Deletion of folder %1$s failed
          */
@@ -722,9 +752,9 @@ public final class IMAPException extends MIMEMailException {
          */
         CONNECT_ERROR(MIMEMailException.Code.CONNECT_ERROR, null),
         /**
-         * Mailbox' root folder must not be source or the destination fullname of a move operation.
+         * Mailbox' root folder must not be source or the destination full name of a move operation.
          */
-        NO_ROOT_MOVE("Mailbox' root folder must not be source or the destination fullname of a move operation.", Category.CODE_ERROR, 2048),
+        NO_ROOT_MOVE("Mailbox' root folder must not be source or the destination full name of a move operation.", Category.CODE_ERROR, 2048),
         /**
          * Sort field %1$s is not supported via IMAP SORT command
          */
@@ -744,7 +774,49 @@ public final class IMAPException extends MIMEMailException {
         /**
          * A SQL error occurred: %1$s
          */
-        SQL_ERROR("A SQL error occurred: %1$s", Category.CODE_ERROR, 2052);
+        SQL_ERROR("A SQL error occurred: %1$s", Category.CODE_ERROR, 2052),
+        /**
+         * Rename of folder "%1$s" to "%2$s" failed with "%3$s".
+         */
+        RENAME_FAILED("Rename of folder \"%1$s\" to \"%2$s\" failed with \"%3$s\".", Category.CODE_ERROR, 2053),
+        /**
+         * Rename of folder "%1$s" to "%2$s" failed on server %3$s with login %4$s (user=%5$s, context=%6$s).
+         */
+        RENAME_FAILED_EXT("Rename of folder \"%1$s\" to \"%2$s\" failed with \"%3$s\" on server %4$s with login %5$s (user=%6$s, context=%7$s).", RENAME_FAILED),
+        /**
+         * No rename access to mail folder %1$s
+         */
+        NO_RENAME_ACCESS("No rename access to mail folder %1$s", Category.PERMISSION, 2054),
+        /**
+         * No rename access to mail folder %1$s on server %2$s with login %3$s (user=%4$s, context=%5$s)
+         */
+        NO_RENAME_ACCESS_EXT("No rename access to mail folder %1$s on server %2$s with login %3$s (user=%4$s, context=%5$s)", NO_RENAME_ACCESS),
+        /**
+         * Unable to parse IMAP server URI "%1$s".
+         */
+        URI_PARSE_FAILED("Unable to parse IMAP server URI \"%1$s\".", Category.SETUP_ERROR, 2055),
+        /**
+         * Default folder %1$s must not be unsubscribed.
+         */
+        NO_DEFAULT_FOLDER_UNSUBSCRIBE("Default folder %1$s must not be unsubscribed.", Category.USER_INPUT, 2056),
+        /**
+         * Default folder %1$s must not be unsubscribed on server %2$s with login %3$s (user=%4$s, context=%5$s)
+         */
+        NO_DEFAULT_FOLDER_UNSUBSCRIBE_EXT("Default folder %1$s must not be unsubscribed on server %2$s with login %3$s (user=%4$s, context=%5$s)", NO_DEFAULT_FOLDER_UNSUBSCRIBE),
+        /**
+         * IMAP server refuses to import one or more E-Mails.
+         */
+        INVALID_MESSAGE("IMAP server refuses to import one or more E-Mails.", Category.USER_INPUT, 2057),
+        /**
+         * IMAP server %1$s refuses to import one or more E-Mails with login %2$s (user=%3$s, context=%3$s)
+         */
+        INVALID_MESSAGE_EXT("IMAP server %1$s refuses to import one or more E-Mails with login %2$s (user=%3$s, context=%4$s)", INVALID_MESSAGE),
+        /**
+         * Currently not possible to establish a new connection to server %1$s with login %2$s. Please try again.
+         */
+        CONNECTION_UNAVAILABLE("Currently not possible to establish a new connection to server %1$s with login %2$s. Please try again.", Category.TRY_AGAIN, 2058),
+
+        ;
 
         private final String message;
 
@@ -756,7 +828,7 @@ public final class IMAPException extends MIMEMailException {
 
         private IMAPCode(final String message, final Category category, final int detailNumber) {
             this.message = message;
-            this.extend = null;
+            extend = null;
             this.detailNumber = detailNumber;
             this.category = category;
         }
@@ -764,8 +836,8 @@ public final class IMAPException extends MIMEMailException {
         private IMAPCode(final String message, final IMAPCode extend) {
             this.message = message;
             this.extend = extend;
-            this.detailNumber = extend.detailNumber;
-            this.category = extend.category;
+            detailNumber = extend.detailNumber;
+            category = extend.category;
         }
 
         private IMAPCode(final MailException.Code code, final IMAPCode extend) {
@@ -809,7 +881,7 @@ public final class IMAPException extends MIMEMailException {
 
         /**
          * Gets the extended code for specified code.
-         * 
+         *
          * @param code The code whose extended version shall be returned
          * @return The extended code for specified code or <code>null</code>
          */
@@ -820,7 +892,7 @@ public final class IMAPException extends MIMEMailException {
 
     /**
      * Throws a new IMAP exception for specified error code.
-     * 
+     *
      * @param code The error code
      * @param imapConfig The IMAP configuration providing account information
      * @param session The session providing user information
@@ -833,7 +905,7 @@ public final class IMAPException extends MIMEMailException {
 
     /**
      * Throws a new IMAP exception for specified error code.
-     * 
+     *
      * @param code The error code
      * @param imapConfig The IMAP configuration providing account information
      * @param session The session providing user information
@@ -846,7 +918,7 @@ public final class IMAPException extends MIMEMailException {
 
     /**
      * Throws a new IMAP exception for specified error code.
-     * 
+     *
      * @param code The error code
      * @param imapConfig The IMAP configuration providing account information
      * @param session The session providing user information
@@ -861,7 +933,7 @@ public final class IMAPException extends MIMEMailException {
 
     /**
      * Creates a new IMAP exception for specified error code.
-     * 
+     *
      * @param code The error code
      * @param imapConfig The IMAP configuration providing account information
      * @param session The session providing user information
@@ -870,6 +942,16 @@ public final class IMAPException extends MIMEMailException {
      * @return The new IMAP exception
      */
     public static IMAPException create(final Code code, final IMAPConfig imapConfig, final Session session, final Throwable cause, final Object... messageArgs) {
+        if (IMAPException.Code.NO_ACCESS.equals(code) && messageArgs[0] != null) {
+            final String fullName = messageArgs[0].toString();
+            if (!MailFolder.DEFAULT_FOLDER_ID.equals(fullName)) {
+                ListLsubCache.removeCachedEntry(fullName, imapConfig.getAccountId(), session);
+                final IMAPStore imapStore = imapConfig.optImapStore();
+                if (null != imapStore) {
+                    IMAPCommandsCollection.forceSetSubscribed(imapStore, fullName, false);
+                }
+            }
+        }
         final IMAPCode imapCode = code.getImapCode();
         if (null != imapConfig && null != session) {
             final IMAPCode extendedCode = IMAPCode.getExtendedCode(imapCode);
@@ -897,7 +979,7 @@ public final class IMAPException extends MIMEMailException {
 
     /**
      * Gets the message corresponding to specified error code with given message arguments applied.
-     * 
+     *
      * @param code The code
      * @param msgArgs The message arguments
      * @return The message corresponding to specified error code with given message arguments applied
@@ -909,7 +991,7 @@ public final class IMAPException extends MIMEMailException {
 
     /**
      * Initializes a new {@link IMAPException}
-     * 
+     *
      * @param cause The cause
      */
     public IMAPException(final AbstractOXException cause) {
