@@ -51,12 +51,9 @@ package com.openexchange.imap;
 
 import static com.openexchange.mail.dataobjects.MailFolder.DEFAULT_FOLDER_ID;
 import java.util.Set;
-import java.util.concurrent.ConcurrentHashMap;
-import java.util.concurrent.ConcurrentMap;
 import javax.mail.Flags;
 import javax.mail.Folder;
 import javax.mail.MessagingException;
-import com.openexchange.config.ConfigurationService;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.contexts.impl.ContextException;
 import com.openexchange.groupware.contexts.impl.ContextStorage;
@@ -67,7 +64,6 @@ import com.openexchange.imap.cache.ListLsubRuntimeException;
 import com.openexchange.imap.cache.RightsCache;
 import com.openexchange.imap.config.IMAPConfig;
 import com.openexchange.imap.notify.internal.IMAPNotifierMessageRecentListener;
-import com.openexchange.imap.services.IMAPServiceRegistry;
 import com.openexchange.mail.MailException;
 import com.openexchange.mail.api.MailMessageStorage;
 import com.openexchange.mail.api.enhanced.MailMessageStorageLong;
@@ -79,7 +75,6 @@ import com.openexchange.mail.usersetting.UserSettingMailStorage;
 import com.openexchange.session.Session;
 import com.sun.mail.imap.DefaultFolder;
 import com.sun.mail.imap.IMAPFolder;
-import com.sun.mail.imap.IMAPStore;
 import com.sun.mail.imap.Rights.Right;
 
 /**
@@ -98,55 +93,6 @@ public abstract class IMAPFolderWorker extends MailMessageStorageLong {
 
     protected static final Flags FLAGS_SEEN = new Flags(Flags.Flag.SEEN);
 
-    private static final class FailFastError {
-
-        final MessagingException error;
-        final long stamp;
-
-        FailFastError(final MessagingException e) {
-            super();
-            this.error = e;
-            this.stamp = System.currentTimeMillis();
-        }
-    }
-
-    private static final ConcurrentMap<String, FailFastError> FAIL_FAST = new ConcurrentHashMap<String, FailFastError>();
-
-    private static volatile Integer failFastTimeout;
-    private static int failFastTimeout() {
-        Integer tmp = failFastTimeout;
-        if (null == tmp) {
-            synchronized (IMAPFolderWorker.class) {
-                tmp = failFastTimeout;
-                if (null == tmp) {
-                    final ConfigurationService service = IMAPServiceRegistry.getService(ConfigurationService.class);
-                    tmp = Integer.valueOf(null == service ? 10000 : service.getIntProperty("com.openexchange.imap.failFastTimeout", 10000));
-                    failFastTimeout = tmp;
-                }
-            }
-        }
-        return tmp.intValue();
-    }
-
-    /**
-     * Checks for possible fail-fast error.
-     * 
-     * @param imapStore The IMAP store to check
-     * @param fullName The mailbox full name
-     * @throws MessagingException If such a fail-fast error exists and has not elapsed, yet
-     */
-    public static void checkFailFast(final IMAPStore imapStore, final String fullName) throws MessagingException {
-        final String key = fullName + '@' + imapStore.toString();
-        final FailFastError failFastError = FAIL_FAST.get(key);
-        if (null == failFastError) {
-            return;
-        }
-        if ((System.currentTimeMillis() - failFastError.stamp) <= failFastTimeout()) {
-            throw failFastError.error;
-        }
-        FAIL_FAST.remove(key, failFastError);
-    }
-
     /*
      * Fields
      */
@@ -194,17 +140,6 @@ public abstract class IMAPFolderWorker extends MailMessageStorageLong {
         aclExtension = imapConfig.getACLExtension();
     }
 
-    private void openFolder(final int desiredMode, final IMAPFolder imapFolder) throws MessagingException {
-        try {
-            imapFolder.open(desiredMode);
-        } catch (final MessagingException e) {
-            if (toUpperCase(e.getMessage()).indexOf("[INUSE]") >= 0) {
-                FAIL_FAST.put(imapFolder.getFullName() + '@' + imapStore.toString(), new FailFastError(e));
-            }
-            throw e;
-        }
-    }
-
     @Override
     public void releaseResources() throws MailException {
         closeIMAPFolder();
@@ -401,7 +336,7 @@ public abstract class IMAPFolderWorker extends MailMessageStorageLong {
                     /*
                      * Open identical folder in right mode
                      */
-                    openFolder(desiredMode, imapFolder);
+                    imapFolder.open(desiredMode);
                     return imapFolder;
                 }
             }
@@ -458,7 +393,7 @@ public abstract class IMAPFolderWorker extends MailMessageStorageLong {
                     session,
                     isDefaultFolder ? MailFolder.DEFAULT_FOLDER_NAME : fullName);
             }
-            openFolder(desiredMode, retval);
+            retval.open(desiredMode);
         }
         return retval;
     }
@@ -477,18 +412,4 @@ public abstract class IMAPFolderWorker extends MailMessageStorageLong {
         return new MailException(MailException.Code.UNEXPECTED_ERROR, e, e.getMessage());
     }
 
-    /** ASCII-wise upper-case */
-    private static String toUpperCase(final CharSequence chars) {
-        if (null == chars) {
-            return null;
-        }
-        final int length = chars.length();
-        final StringBuilder builder = new StringBuilder(length);
-        for (int i = 0; i < length; i++) {
-            final char c = chars.charAt(i);
-            builder.append((c >= 'a') && (c <= 'z') ? (char) (c & 0x5f) : c);
-        }
-        return builder.toString();
-    }
-
 }
