@@ -250,7 +250,7 @@ public final class IMAPStoreCache {
         }
     }
 
-    private IMAPStoreContainer getContainer(final int accountId, final String server, final int port, final String login, final String pw, final Session session, final IMAPValidity validity) throws MailException {
+    private IMAPStoreContainer getContainer(final int accountId, final String server, final int port, final String login, final String pw, final Session session) throws MailException {
         /*
          * Check for a cached one
          */
@@ -320,10 +320,10 @@ public final class IMAPStoreCache {
          */
         try {
             if (!DEBUG) {
-                return getContainer(accountId, server, port, login, pw, session, validity).getStore(imapSession, validity);
+                return getContainer(accountId, server, port, login, pw, session).getStore(imapSession, validity);
             }
             final long st = System.currentTimeMillis();
-            final IMAPStore store = getContainer(accountId, server, port, login, pw, session, validity).getStore(imapSession, validity);
+            final IMAPStore store = getContainer(accountId, server, port, login, pw, session).getStore(imapSession, validity);
             final long dur = System.currentTimeMillis() - st;
             LOG.debug("IMAPStoreCache.borrowIMAPStore() took " + dur + "msec.");
             return store;
