@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -55,18 +55,18 @@ import com.openexchange.server.Initialization;
 
 /**
  * {@link ACLExtensionInit} - Initialization for ACL extension.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class ACLExtensionInit implements Initialization {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(ACLExtensionInit.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(ACLExtensionInit.class));
 
     private static final ACLExtensionInit instance = new ACLExtensionInit();
 
     /**
      * Gets the initialization for ACL extension.
-     * 
+     *
      * @return The initialization for ACL extension.
      */
     public static ACLExtensionInit getInstance() {
@@ -91,10 +91,10 @@ public final class ACLExtensionInit implements Initialization {
             return;
         }
         ACLExtensionFactory.createInstance();
-        ACLExtensionAutoDetector.initACLExtensionMappings();
+        // ACLExtensionAutoDetector.initACLExtensionMappings();
         // TODO: Uncomment subsequent code to enable configured instance rather than auto-detection
         /*-
-         * 
+         *
         synchronized(this) {
             if (null == implementingClass) {
                 final String classNameProp = IMAPConfig.getEntity2AclImpl();
@@ -134,7 +134,7 @@ public final class ACLExtensionInit implements Initialization {
             return;
         }
         ACLExtensionFactory.getInstance().resetACLExtensionFactory();
-        ACLExtensionAutoDetector.resetACLExtensionMappings();
+        // ACLExtensionAutoDetector.resetACLExtensionMappings();
         ACLExtensionFactory.releaseInstance();
     }
 
