@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -66,7 +66,7 @@ import com.sun.mail.imap.Rights.Right;
  * <p>
  * If a client includes the "c" right in a rights list, then it MUST be treated as if the client had included every member of the "create"
  * right.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 class RFC4314ACLExtension extends AbstractACLExtension {
@@ -77,6 +77,11 @@ class RFC4314ACLExtension extends AbstractACLExtension {
      */
     private static final transient Rights RIGHTS_FOLDER_ADMIN = new Rights("aclkx");
 
+    /**
+     * "al": {@link Right#ADMINISTER} + {@link Right#LOOKUP}
+     */
+    private static final transient Rights RIGHTS_FOLDER_ADMIN_UNION = new Rights("al");
+
     /**
      * "l": {@link Right#LOOKUP}
      */
@@ -93,6 +98,12 @@ class RFC4314ACLExtension extends AbstractACLExtension {
      */
     private static final transient Rights RIGHTS_FOLDER_CREATE_SUBFOLDERS = new Rights("cilkx");
 
+    /**
+     * The "create" right is the union of the "k" and "x" rights.<br>
+     * "kx": {@link RFC4314Rights#CREATE_MAILBOXES} + {@link RFC4314Rights#DELETE_MAILBOX}.
+     */
+    private static final transient Rights RIGHTS_CREATE_RFC4314 = new Rights("kx");
+
     /**
      * "rs": {@link Right#READ} + {@link Right#KEEP_SEEN}
      */
@@ -113,6 +124,12 @@ class RFC4314ACLExtension extends AbstractACLExtension {
      */
     private static final transient Rights RIGHTS_DELETE_ALL = new Rights("det");
 
+    /**
+     * The "delete" right is the union of the "e" and "t" rights.<br>
+     * "et": {@link RFC4314Rights#EXPUNGE} + {@link RFC4314Rights#DELETE_MESSAGES}
+     */
+    private static final transient Rights RIGHTS_DELETE_UNION = new Rights("et");
+
     /**
      * "p": {@link Right#POST}
      */
@@ -161,7 +178,7 @@ class RFC4314ACLExtension extends AbstractACLExtension {
     }
 
     public boolean containsFolderAdminRights(final Rights rights) {
-        return rights.contains(RIGHTS_FOLDER_ADMIN);
+        return rights.contains(RIGHTS_FOLDER_ADMIN_UNION) && (rights.contains(Rights.Right.CREATE) || rights.contains(RIGHTS_CREATE_RFC4314));
     }
 
     public void addFolderVisibility(final Rights rights) {
@@ -205,11 +222,11 @@ class RFC4314ACLExtension extends AbstractACLExtension {
     }
 
     public boolean containsCreateSubfolders(final Rights rights) {
-        return rights.contains(RIGHTS_FOLDER_CREATE_SUBFOLDERS);
+        return rights.contains(RIGHTS_FOLDER_CREATE_OBJECTS) && (rights.contains(Rights.Right.CREATE) || rights.contains(RIGHTS_CREATE_RFC4314));
     }
 
     public boolean containsDeleteAll(final Rights rights) {
-        return rights.contains(RIGHTS_DELETE_ALL);
+        return rights.contains(Rights.Right.DELETE) || rights.contains(RIGHTS_DELETE_UNION);
     }
 
     public boolean containsNonMappable(final Rights rights) {
