@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -59,11 +59,14 @@ import java.util.concurrent.Future;
 import java.util.concurrent.FutureTask;
 import javax.mail.MessagingException;
 import com.openexchange.imap.IMAPCommandsCollection;
+import com.openexchange.imap.config.IMAPConfig;
+import com.openexchange.mail.MailException;
+import com.openexchange.mail.mime.MIMEMailException;
 import com.sun.mail.imap.IMAPFolder;
 
 /**
  * {@link MBoxEnabledCache} - A cache to check for MBox feature for a certain IMAP server.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class MBoxEnabledCache {
@@ -113,22 +116,28 @@ public final class MBoxEnabledCache {
 
     /**
      * Checks if MBox feature is enabled for given IMAP server.
-     * 
-     * @param imapServer The IMAP server's address
+     *
+     * @param imapConfig The IMAP configuration
      * @param imapFolder The IMAP folder to test with
-     * @param prefix The fullname prefix to use
+     * @param prefix The full name prefix to use
      * @return <code>true</code> if MBox feature is enabled; otherwise <code>false</code>
+     * @throws MailException If a mail error occurs
      * @throws MessagingException If a messaging error occurs
      */
-    public static boolean isMBoxEnabled(final InetSocketAddress imapServer, final IMAPFolder imapFolder, final String prefix) throws MessagingException {
+    public static boolean isMBoxEnabled(final IMAPConfig imapConfig, final IMAPFolder imapFolder, final String prefix) throws MailException, MessagingException {
         final ConcurrentMap<InetSocketAddress, Future<Boolean>> map = MAP;
-        Future<Boolean> f = map.get(imapServer);
+        Future<Boolean> f = map.get(imapConfig.getImapServerSocketAddress());
         if (null == f) {
-            final FutureTask<Boolean> ft = new FutureTask<Boolean>(new MBoxEnabledCallable(imapFolder, prefix));
-            f = map.putIfAbsent(imapServer, ft);
+            final SettableFutureTask<Boolean> ft = new SettableFutureTask<Boolean>(new MBoxEnabledCallable(imapFolder, prefix));
+            f = map.putIfAbsent(imapConfig.getImapServerSocketAddress(), ft);
             if (null == f) {
                 f = ft;
-                ft.run();
+                final Boolean mbox = ListLsubCache.consideredAsMBox(imapConfig.getAccountId(), imapFolder, imapConfig.getSession());
+                if (null == mbox) {
+                    ft.run();
+                } else {
+                    ft.set(mbox);
+                }
             }
         }
         try {
@@ -136,16 +145,16 @@ public final class MBoxEnabledCache {
         } catch (final InterruptedException e) {
             // Keep interrupted status
             Thread.currentThread().interrupt();
-            throw new MessagingException(e.getMessage());
+            throw new MailException(MailException.Code.INTERRUPT_ERROR, e, e.getMessage());
         } catch (final CancellationException e) {
-            throw new MessagingException(e.getMessage());
+            throw new MailException(MailException.Code.UNEXPECTED_ERROR, e, e.getMessage());
         } catch (final ExecutionException e) {
             final Throwable cause = e.getCause();
             if (cause instanceof MessagingException) {
-                throw ((MessagingException) cause);
+                throw MIMEMailException.handleMessagingException((MessagingException) cause, imapConfig);
             }
             if (cause instanceof RuntimeException) {
-                throw new MessagingException(e.getMessage());
+                throw new MailException(MailException.Code.UNEXPECTED_ERROR, e, e.getMessage());
             }
             if (cause instanceof Error) {
                 throw (Error) cause;
@@ -174,4 +183,17 @@ public final class MBoxEnabledCache {
 
     }
 
+    private static final class SettableFutureTask<V> extends FutureTask<V> {
+
+        public SettableFutureTask(final Callable<V> callable) {
+            super(callable);
+        }
+
+        @Override
+        public void set(final V v) {
+            super.set(v);
+        }
+
+    }
+
 }
