@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -63,11 +63,15 @@ import com.sun.mail.imap.IMAPFolder;
 
 /**
  * {@link UserFlagsCache}
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class UserFlagsCache {
 
+    private static final boolean CHECK_ONCE = true;
+
+    private static final String INBOX = "INBOX";
+
     /**
      * No instance
      */
@@ -77,7 +81,7 @@ public final class UserFlagsCache {
 
     /**
      * Determines if specified IMAP folder supports user flags
-     * 
+     *
      * @param f The IMAP folder
      * @param load Whether the <code>SELECT</code> command should be invoked on IMAP folder or not
      * @param session The session providing the session-bound cache
@@ -86,7 +90,7 @@ public final class UserFlagsCache {
      * @throws MessagingException If <code>SELECT</code> command fails
      */
     public static boolean supportsUserFlags(final IMAPFolder f, final boolean load, final Session session, final int accountId) throws MessagingException {
-        final UserFlagCacheEntry entry = new UserFlagCacheEntry(f.getFullName());
+        final UserFlagCacheEntry entry = new UserFlagCacheEntry(CHECK_ONCE ? INBOX : f.getFullName());
         final SessionMailCache mailCache = SessionMailCache.getInstance(session, accountId);
         mailCache.get(entry);
         if (load && (null == entry.getValue())) {
@@ -107,7 +111,7 @@ public final class UserFlagsCache {
 
     /**
      * Removes cached information if given IMAP folder supports user flags
-     * 
+     *
      * @param f The IMAP folder
      * @param session The session providing the session-bound cache
      * @param accountId The account ID
@@ -116,13 +120,24 @@ public final class UserFlagsCache {
         SessionMailCache.getInstance(session, accountId).remove(new UserFlagCacheEntry(f.getFullName()));
     }
 
+    /**
+     * Removes cached information if given IMAP folder supports user flags
+     *
+     * @param fullName The IMAP folder full name
+     * @param session The session providing the session-bound cache
+     * @param accountId The account ID
+     */
+    public static void removeUserFlags(final String fullName, final Session session, final int accountId) {
+        SessionMailCache.getInstance(session, accountId).remove(new UserFlagCacheEntry(fullName));
+    }
+
     private static final class UserFlagCacheEntry implements SessionMailCacheEntry<Boolean> {
 
         private final String fullname;
 
-        private Boolean value;
+        private volatile Boolean value;
 
-        private CacheKey key;
+        private volatile CacheKey key;
 
         public UserFlagCacheEntry(final String fullname) {
             super();
@@ -130,10 +145,11 @@ public final class UserFlagsCache {
         }
 
         private CacheKey getKeyInternal() {
-            if (null == key) {
-                key = IMAPServiceRegistry.getService(CacheService.class).newCacheKey(MailCacheCode.USER_FLAGS.getCode(), fullname);
+            CacheKey tmp = key;
+            if (null == tmp) {
+                key = tmp = IMAPServiceRegistry.getService(CacheService.class).newCacheKey(MailCacheCode.USER_FLAGS.getCode(), fullname);
             }
-            return key;
+            return tmp;
         }
 
         public CacheKey getKey() {
