@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -59,14 +59,13 @@ import javax.mail.FetchProfile;
 import javax.mail.Flags;
 import javax.mail.Header;
 import javax.mail.Message;
+import javax.mail.Message.RecipientType;
 import javax.mail.MessagingException;
 import javax.mail.UIDFolder;
-import javax.mail.Message.RecipientType;
 import javax.mail.internet.InternetHeaders;
 import com.openexchange.imap.IMAPCommandsCollection;
 import com.openexchange.mail.MailException;
 import com.openexchange.mail.MailListField;
-import com.openexchange.mail.config.MailProperties;
 import com.openexchange.mail.mime.ContentType;
 import com.openexchange.mail.mime.ExtendedMimeMessage;
 import com.openexchange.mail.mime.MIMEMailException;
@@ -75,6 +74,7 @@ import com.openexchange.mail.mime.MessageHeaders;
 import com.openexchange.mail.mime.utils.MIMEMessageUtility;
 import com.sun.mail.iap.Response;
 import com.sun.mail.imap.IMAPFolder;
+import com.sun.mail.imap.IMAPFolder.FetchProfileItem;
 import com.sun.mail.imap.protocol.BODY;
 import com.sun.mail.imap.protocol.BODYSTRUCTURE;
 import com.sun.mail.imap.protocol.ENVELOPE;
@@ -93,12 +93,12 @@ import com.sun.mail.imap.protocol.UID;
  * This method avoids calling JavaMail's fetch() methods which implicitly requests whole message envelope (FETCH 1:* (ENVELOPE INTERNALDATE
  * RFC822.SIZE)) when later working on returned <code>javax.mail.Message</code> objects.
  * </p>
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class FetchIMAPCommand extends AbstractIMAPCommand<Message[]> {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(FetchIMAPCommand.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(FetchIMAPCommand.class));
 
     private static interface SeqNumFetcher {
 
@@ -122,7 +122,7 @@ public final class FetchIMAPCommand extends AbstractIMAPCommand<Message[]> {
             /*
              * Create delegate
              */
-            this.delegate = new IntSeqNumFetcher(arr);
+            delegate = new IntSeqNumFetcher(arr);
         }
 
         public int getNextSeqNum(final int index) {
@@ -178,7 +178,7 @@ public final class FetchIMAPCommand extends AbstractIMAPCommand<Message[]> {
 
     /**
      * Initializes a new {@link FetchIMAPCommand}.
-     * 
+     *
      * @param imapFolder - the IMAP folder
      * @param isRev1 Whether IMAP server has <i>IMAP4rev1</i> capability or not
      * @param arr - the source array (either <code>long</code> UIDs, <code>int</code> SeqNums or instances of <code>Message</code>)
@@ -194,7 +194,7 @@ public final class FetchIMAPCommand extends AbstractIMAPCommand<Message[]> {
 
     /**
      * Initializes a new {@link FetchIMAPCommand}.
-     * 
+     *
      * @param imapFolder - the IMAP folder
      * @param isRev1 Whether IMAP server has <i>IMAP4rev1</i> capability or not
      * @param arr - the source array (either <code>long</code> UIDs, <code>int</code> SeqNums or instances of <code>Message</code>)
@@ -207,18 +207,18 @@ public final class FetchIMAPCommand extends AbstractIMAPCommand<Message[]> {
      */
     public FetchIMAPCommand(final IMAPFolder imapFolder, final boolean isRev1, final Object arr, final FetchProfile fp, final boolean isSequential, final boolean keepOrder, final boolean loadBody) throws MessagingException {
         super(imapFolder);
-        if (imapFolder.getMessageCount() == 0) {
+        if (imapFolder.getMessageCount() <= 0) {
             returnDefaultValue = true;
         }
         this.loadBody = loadBody;
-        this.separator = imapFolder.getSeparator();
+        separator = imapFolder.getSeparator();
         command = getFetchCommand(isRev1, fp, loadBody);
         set(arr, isSequential, keepOrder);
     }
 
     /**
      * Apply a new numeric argument to this IMAP <i>FETCH</i> command
-     * 
+     *
      * @param arr - the source array (either <code>long</code> UIDs, <code>int</code> SeqNums or instances of <code>Message</code>)
      * @param isSequential whether the source array values are sequential
      * @param keepOrder whether to keep or to ignore given order through parameter <code>arr</code>; only has effect if parameter
@@ -239,7 +239,7 @@ public final class FetchIMAPCommand extends AbstractIMAPCommand<Message[]> {
      * Sets whether detection if message contains attachment is performed by "Content-Type" header only.
      * <p>
      * If <code>true</code> a message is considered to contain attachments if its "Content-Type" header equals "multipart/mixed".
-     * 
+     *
      * @param determineAttachmentByHeader <code>true</code> to detect if message contains attachment is performed by "Content-Type" header
      *            only; otherwise <code>false</code>
      * @return This FETCH IMAP command with value applied
@@ -323,7 +323,7 @@ public final class FetchIMAPCommand extends AbstractIMAPCommand<Message[]> {
      * Constructor to fetch all messages of given folder
      * <p>
      * <b>Note</b>: Ensure that denoted folder is not empty through {@link IMAPFolder#getMessageCount()}.
-     * 
+     *
      * @param imapFolder - the IMAP folder
      * @param isRev1 Whether IMAP server has <i>IMAP4rev1</i> capability or not
      * @param fp - the fetch profile
@@ -338,7 +338,7 @@ public final class FetchIMAPCommand extends AbstractIMAPCommand<Message[]> {
      * Constructor to fetch all messages of given folder
      * <p>
      * <b>Note</b>: Ensure that denoted folder is not empty through {@link IMAPFolder#getMessageCount()}.
-     * 
+     *
      * @param imapFolder - the IMAP folder
      * @param isRev1 Whether IMAP server has <i>IMAP4rev1</i> capability or not
      * @param fp - the fetch profile
@@ -348,15 +348,16 @@ public final class FetchIMAPCommand extends AbstractIMAPCommand<Message[]> {
      */
     public FetchIMAPCommand(final IMAPFolder imapFolder, final boolean isRev1, final FetchProfile fp, final int fetchLen, final boolean loadBody) throws MessagingException {
         super(imapFolder);
-        if (imapFolder.getMessageCount() == 0) {
+        final int messageCount = imapFolder.getMessageCount();
+        if (messageCount <= 0) {
             returnDefaultValue = true;
         }
         this.loadBody = loadBody;
-        this.separator = imapFolder.getSeparator();
+        separator = imapFolder.getSeparator();
         if (0 == fetchLen) {
             returnDefaultValue = true;
         }
-        args = AbstractIMAPCommand.ARGS_ALL;
+        args = 1 == messageCount ? new String[] { "1" } : ARGS_ALL;
         uid = false;
         length = fetchLen;
         command = getFetchCommand(isRev1, fp, loadBody);
@@ -371,7 +372,7 @@ public final class FetchIMAPCommand extends AbstractIMAPCommand<Message[]> {
             sb.append("UID ");
         }
         sb.append("FETCH ");
-        final String arg = this.args[argsIndex];
+        final String arg = args[argsIndex];
         if (arg.length() > 32) {
             final int pos = arg.indexOf(',');
             if (pos == -1) {
@@ -423,20 +424,22 @@ public final class FetchIMAPCommand extends AbstractIMAPCommand<Message[]> {
             if (pos >= 0 && ++pos < server.length()) {
                 server = server.substring(pos);
             }
-            throw new MessagingException(
-                new StringBuilder(32).append("Expected ").append(length).append(" FETCH responses but got ").append(index).append(
-                    " from IMAP folder \"").append(imapFolder.getFullName()).append("\" on server \"").append(server).append("\".").toString());
+            final MessagingException e =
+                new MessagingException(new StringBuilder(32).append("Expected ").append(length).append(" FETCH responses but got ").append(
+                    index).append(" from IMAP folder \"").append(imapFolder.getFullName()).append("\" on server \"").append(server).append(
+                    "\".").toString());
+            LOG.warn(e.getMessage(), e);
         }
         return retval;
     }
 
     @Override
-    protected void handleResponse(final Response currentReponse) throws MessagingException {
+    protected boolean handleResponse(final Response currentReponse) throws MessagingException {
         /*
          * Response is null or not a FetchResponse
          */
         if (!FetchResponse.class.isInstance(currentReponse)) {
-            return;
+            return false;
         }
         final FetchResponse fetchResponse = (FetchResponse) currentReponse;
         int seqnum;
@@ -508,6 +511,7 @@ public final class FetchIMAPCommand extends AbstractIMAPCommand<Message[]> {
         if (!error) {
             retval[pos] = msg;
         }
+        return true;
     }
 
     private static final Set<Integer> ENV_FIELDS;
@@ -630,7 +634,7 @@ public final class FetchIMAPCommand extends AbstractIMAPCommand<Message[]> {
 
         /**
          * Handles given <code>com.sun.mail.imap.protocol.Item</code> instance and applies it to given message.
-         * 
+         *
          * @param item The item to handle
          * @param msg The message to apply to
          * @param logger The logger
@@ -680,7 +684,7 @@ public final class FetchIMAPCommand extends AbstractIMAPCommand<Message[]> {
                     msg.addHeader(name, hdr.getValue());
                 }
                 /*-
-                 * 
+                 *
                 final HeaderHandler hdrHandler = hdrHandlers.get(hdr.getName());
                 if (hdrHandler == null) {
                     msg.setHeader(hdr.getName(), hdr.getValue());
@@ -717,38 +721,7 @@ public final class FetchIMAPCommand extends AbstractIMAPCommand<Message[]> {
             msg.setReplyTo(env.replyTo);
             msg.setHeader(MessageHeaders.HDR_IN_REPLY_TO, env.inReplyTo);
             msg.setHeader(MessageHeaders.HDR_MESSAGE_ID, env.messageId);
-            /*-
-             * Hmm... Why does ENVELOPE FETCH response omit CR?LFs in subject?!
-             * 
-             * Example:
-             * Subject: =?UTF-8?Q?Nur_noch_kurze_Zeit:_1_Freimona?=
-             *  =?UTF-8?Q?t_f=C3=BCr_3_erfolgreiche_Einladungen?=
-             *  
-             * is transferred as:
-             * =?UTF-8?Q?Nur_noch_kurze_Zeit:_1_Freimona?= =?UTF-8?Q?t_f=C3=BCr_3_erfolgreiche_Einladungen?=
-             */
-            final String subject;
-            if (null == env.subject) {
-                subject = "";
-            } else {
-                final String subj = MIMEMessageUtility.checkNonAscii(env.subject);
-                final char[] chars = subj.toCharArray();
-                final StringBuilder sb = new StringBuilder(chars.length);
-                int i = 0;
-                while (i < chars.length) {
-                    final char c = chars[i];
-                    if ('\t' != c && '\r' != c && '\n' != c) {
-                        if (' ' == c && (i + 1) < chars.length && ' ' == chars[i + 1]) {
-                            i++;
-                        }
-                        sb.append(c);
-                    }
-                    i++;
-                }
-                subject = MIMEMessageUtility.decodeEnvelopeHeader(sb.toString());
-            }
-            msg.setSubject(subject, MailProperties.getInstance().getDefaultMimeCharset());
-
+            msg.setSubject(MIMEMessageUtility.decodeEnvelopeSubject(env.subject));
             msg.setSentDate(env.date);
         }
     };
@@ -843,7 +816,7 @@ public final class FetchIMAPCommand extends AbstractIMAPCommand<Message[]> {
 
     /**
      * Turns given fetch profile into FETCH items to craft a FETCH command.
-     * 
+     *
      * @param isRev1 Whether IMAP protocol is revision 1 or not
      * @param fp The fetch profile to convert
      * @param loadBody <code>true</code> if message body should be loaded; otherwise <code>false</code>
@@ -922,9 +895,70 @@ public final class FetchIMAPCommand extends AbstractIMAPCommand<Message[]> {
         return command.toString();
     }
 
+    /**
+     * Possibly modifies a {@link FetchProfile}.
+     */
+    public static interface FetchProfileModifier {
+
+        /**
+         * Modifies specified {@link FetchProfile} instance.
+         *
+         * @param fetchProfile The fetch profile
+         * @return The modified fetch profile
+         */
+        FetchProfile modify(FetchProfile fetchProfile);
+
+        boolean byContentTypeHeader();
+    }
+
+    /**
+     * Default modifier which returns the fetch profile unchanged.
+     */
+    public static final FetchProfileModifier DEFAULT_PROFILE_MODIFIER = new FetchProfileModifier() {
+
+        public FetchProfile modify(final FetchProfile fetchProfile) {
+            /*
+             * Return unchanged
+             */
+            return fetchProfile;
+        }
+
+        public boolean byContentTypeHeader() {
+            return false;
+        }
+    };
+
+    /**
+     * Strips individual header names from fetch profile, but inserts {@link FetchProfileItem#HEADERS}.
+     */
+    public static final FetchProfileModifier HEADERLESS_PROFILE_MODIFIER = new FetchProfileModifier() {
+
+        public FetchProfile modify(final FetchProfile fetchProfile) {
+            return getHeaderlessFetchProfile(fetchProfile);
+        }
+
+        public boolean byContentTypeHeader() {
+            return false;
+        }
+    };
+
+    /**
+     * Strips BODYSTRUCTURE fetch item and inserts "Content-Type" header name.
+     */
+    public static final FetchProfileModifier NO_BODYSTRUCTURE_PROFILE_MODIFIER = new FetchProfileModifier() {
+
+        public FetchProfile modify(final FetchProfile fetchProfile) {
+            return getSafeFetchProfile(fetchProfile);
+        }
+
+        public boolean byContentTypeHeader() {
+            return true;
+        }
+    };
+
     /**
      * Strips BODYSTRUCTURE item from given fetch profile.
-     * 
+     *
      * @param fetchProfile The fetch profile
      * @return The fetch profile with BODYSTRUCTURE item stripped
      */
@@ -935,8 +969,7 @@ public final class FetchIMAPCommand extends AbstractIMAPCommand<Message[]> {
             if (!fetchProfile.contains(UIDFolder.FetchProfileItem.UID)) {
                 newFetchProfile.add(UIDFolder.FetchProfileItem.UID);
             }
-            final javax.mail.FetchProfile.Item[] items = fetchProfile.getItems();
-            for (final javax.mail.FetchProfile.Item item : items) {
+            for (final javax.mail.FetchProfile.Item item : fetchProfile.getItems()) {
                 if (!FetchProfile.Item.CONTENT_INFO.equals(item)) {
                     newFetchProfile.add(item);
                 }
@@ -950,4 +983,26 @@ public final class FetchIMAPCommand extends AbstractIMAPCommand<Message[]> {
         return fetchProfile;
     }
 
+    /**
+     * Strips header names from given fetch profile.
+     *
+     * @param fetchProfile The fetch profile
+     * @return The fetch profile with header names stripped
+     */
+    public static final FetchProfile getHeaderlessFetchProfile(final FetchProfile fetchProfile) {
+        final String[] headerNames = fetchProfile.getHeaderNames();
+        if (null == headerNames || headerNames.length <= 0) {
+            return fetchProfile;
+        }
+        /*
+         * Strip header names
+         */
+        final FetchProfile newFetchProfile = new FetchProfile();
+        for (final javax.mail.FetchProfile.Item item : fetchProfile.getItems()) {
+            newFetchProfile.add(item);
+        }
+        newFetchProfile.add(IMAPFolder.FetchProfileItem.HEADERS);
+        return newFetchProfile;
+    }
+
 }
