@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,20 +49,21 @@
 
 package com.openexchange.imap.command;
 
-import gnu.trove.TIntArrayList;
-import gnu.trove.TLongArrayList;
+import gnu.trove.list.TIntList;
+import gnu.trove.list.array.TIntArrayList;
+import gnu.trove.list.array.TLongArrayList;
 import java.util.ArrayList;
 import java.util.List;
 import javax.mail.Message;
 
 /**
  * {@link IMAPNumArgSplitter}
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class IMAPNumArgSplitter {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(IMAPNumArgSplitter.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(IMAPNumArgSplitter.class));
 
     private static interface Tokenizer {
 
@@ -83,7 +84,7 @@ public final class IMAPNumArgSplitter {
 
     /**
      * From <a href="http://www.faqs.org/rfcs/rfc2683.html">RFC 2683</a> section 3.2.1.5. (Long Command Lines):<br>
-     * 
+     *
      * <pre>
      * &quot;
      * ...
@@ -94,7 +95,7 @@ public final class IMAPNumArgSplitter {
      * split the request into multiple commands.  The client should use
      * literals instead of long quoted strings, in order to keep the command
      * length down.
-     * 
+     *
      * For its part, a server should allow for a command line of at least
      * 8000 octets.  This provides plenty of leeway for accepting reasonable
      * length commands from clients.  The server should send a BAD response
@@ -112,7 +113,7 @@ public final class IMAPNumArgSplitter {
     /**
      * Since an IMAP command MUST NOT exceed the maximum command length of the IMAP server, which is 8000 bytes, this method creates an
      * appropriate array of command arguments which can then be used with an instance of <code>{@link AbstractIMAPCommand}</code>
-     * 
+     *
      * @param arr - <code>int</code> array of message sequence numbers
      * @return an appropriate array of command arguments
      */
@@ -128,7 +129,7 @@ public final class IMAPNumArgSplitter {
     /**
      * Since an IMAP command MUST NOT exceed the maximum command length of the IMAP server, which is 8000 bytes, this method creates an
      * appropriate array of command arguments which can then be used with an instance of <code>{@link AbstractIMAPCommand}</code>
-     * 
+     *
      * @param arr - <code>long</code> array of message UIDs
      * @return an appropriate array of command arguments
      */
@@ -144,7 +145,7 @@ public final class IMAPNumArgSplitter {
     /**
      * Since an IMAP command MUST NOT exceed the maximum command length of the IMAP server, which is 8000 bytes, this method creates an
      * appropriate array of command arguments which can then be used with an instance of <code>{@link AbstractIMAPCommand}</code>
-     * 
+     *
      * @param arr - <code>Message</code> array
      * @return an appropriate array of command arguments
      */
@@ -160,7 +161,7 @@ public final class IMAPNumArgSplitter {
     /**
      * Given array of sequence numbers is first transformed into a valid IMAP command's number argument and then split into max. IMAP
      * command length pieces
-     * 
+     *
      * @param arr - the array of sequence numbers
      * @param keepOrder - whether the values' ordering in array parameter <code>arr</code> shall be kept or not; if ordering does not care a
      *            more compact number argument for IMAP command is going to be created by grouping sequential numbers e.g.
@@ -175,7 +176,7 @@ public final class IMAPNumArgSplitter {
     /**
      * Given array of sequence numbers is first transformed into a valid IMAP command's number argument and then split into max. IMAP
      * command length pieces if desired.
-     * 
+     *
      * @param arr - the array of sequence numbers
      * @param keepOrder - whether the values' ordering in array parameter <code>arr</code> shall be kept or not; if ordering does not care a
      *            more compact number argument for IMAP command is going to be created by grouping sequential numbers e.g.
@@ -185,7 +186,7 @@ public final class IMAPNumArgSplitter {
      * @return an appropriate array of command arguments
      */
     public static String[] getSeqNumArg(final int[] arr, final boolean keepOrder, final boolean split, final int consumed) {
-        final TIntArrayList l = new TIntArrayList(arr.length);
+        final TIntList l = new TIntArrayList(arr.length);
         for (int i = 0; i < arr.length; i++) {
             final int seqNum = arr[i];
             if (seqNum > 0) {
@@ -206,7 +207,7 @@ public final class IMAPNumArgSplitter {
     /**
      * Given array of sequence numbers is first transformed into a valid IMAP command's number argument and then split into max. IMAP
      * command length pieces
-     * 
+     *
      * @param arr - the array of sequence numbers
      * @param keepOrder - whether the values' ordering in array parameter <code>arr</code> shall be kept or not; if ordering does not care a
      *            more compact number argument for IMAP command is going to be created by grouping sequential numbers e.g.
@@ -215,7 +216,7 @@ public final class IMAPNumArgSplitter {
      * @return an appropriate array of command arguments
      */
     public static String[] splitMessageArg(final Message[] arr, final boolean keepOrder, final int consumed) {
-        final TIntArrayList l = new TIntArrayList(arr.length);
+        final TIntList l = new TIntArrayList(arr.length);
         for (int i = 0; i < arr.length; i++) {
             final int messageNumber = arr[i].getMessageNumber();
             if (messageNumber > 0) {
@@ -234,7 +235,7 @@ public final class IMAPNumArgSplitter {
     /**
      * Given array of sequence numbers is first transformed into a valid IMAP command's number argument and then split into max. IMAP
      * command length pieces
-     * 
+     *
      * @param arr - the array of sequence numbers
      * @param keepOrder - whether the values' ordering in array parameter <code>arr</code> shall be kept or not; if ordering does not care a
      *            more compact number argument for IMAP command is going to be created by grouping sequential numbers e.g.
@@ -268,21 +269,21 @@ public final class IMAPNumArgSplitter {
      * 8000 bytes
      * <p>
      * A resulting string can look like this: <code>10031:10523,10525:11020,11022:11027,11030:11047,11050:11051,11053,11055:11558</code>
-     * 
+     *
      * @param numbers The list of numbers; either sequence numbers or UIDs
      * @return The number argument or an empty string if specified numbers are empty
      */
-    public static String getNumArg(final TIntArrayList numbers) {
+    public static String getNumArg(final TIntList numbers) {
         final int size = numbers.size();
         if (0 == size) {
             return "";
         }
-        int prev = numbers.getQuick(0);
+        int prev = numbers.get(0);
         boolean contiguous = false;
         final StringBuilder sb = new StringBuilder(size << 2);
         sb.append(prev);
         for (int i = 1; i < size; i++) {
-            final int current = numbers.getQuick(i);
+            final int current = numbers.get(i);
             if (prev + 1 == current) {
                 prev++;
                 contiguous = true;
@@ -313,7 +314,7 @@ public final class IMAPNumArgSplitter {
      * 8000 bytes
      * <p>
      * A resulting string can look like this: <code>10031:10523,10525:11020,11022:11027,11030:11047,11050:11051,11053,11055:11558</code>
-     * 
+     *
      * @param numbers The list of numbers; either sequence numbers or UIDs
      * @return The number argument or an empty string if specified numbers are empty
      */
@@ -322,12 +323,12 @@ public final class IMAPNumArgSplitter {
         if (0 == size) {
             return "";
         }
-        long prev = numbers.getQuick(0);
+        long prev = numbers.get(0);
         boolean contiguous = false;
         final StringBuilder sb = new StringBuilder(size << 2);
         sb.append(prev);
         for (int i = 1; i < size; i++) {
-            final long current = numbers.getQuick(i);
+            final long current = numbers.get(i);
             if (prev + 1 == current) {
                 prev++;
                 contiguous = true;
