@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -60,7 +60,7 @@ import com.sun.mail.imap.protocol.UID;
 /**
  * {@link MessageUIDsIMAPCommand} - gets the corresponding message UIDs to given array of <code>Message</code> as an array of
  * <code>long</code>
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class MessageUIDsIMAPCommand extends AbstractIMAPCommand<long[]> {
@@ -75,7 +75,7 @@ public final class MessageUIDsIMAPCommand extends AbstractIMAPCommand<long[]> {
 
     /**
      * Initializes a new {@link MessageUIDsIMAPCommand}
-     * 
+     *
      * @param imapFolder The IMAP folder
      * @param msgs The messages
      */
@@ -125,17 +125,19 @@ public final class MessageUIDsIMAPCommand extends AbstractIMAPCommand<long[]> {
     }
 
     @Override
-    protected void handleResponse(final Response response) throws MessagingException {
+    protected boolean handleResponse(final Response response) throws MessagingException {
         /*
          * Response is null or not a FetchResponse
          */
         if (response == null) {
-            return;
-        } else if (!(response instanceof FetchResponse)) {
-            return;
+            return true;
+        }
+        if (!(response instanceof FetchResponse)) {
+            return false;
         }
         sla.append(((UID) (((FetchResponse) response).getItem(0))).uid);
         index++;
+        return true;
     }
 
 }
