@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -58,12 +58,12 @@ import com.sun.mail.imap.protocol.UID;
 
 /**
  * {@link SeqNumIMAPCommand}
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class SeqNumIMAPCommand extends AbstractIMAPCommand<int[]> {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(SeqNumIMAPCommand.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(SeqNumIMAPCommand.class));
 
     private static final long[] L1 = new long[0];
 
@@ -122,9 +122,9 @@ public final class SeqNumIMAPCommand extends AbstractIMAPCommand<int[]> {
     }
 
     @Override
-    protected void handleResponse(final Response response) throws MessagingException {
+    protected boolean handleResponse(final Response response) throws MessagingException {
         if (!(response instanceof FetchResponse)) {
-            return;
+            return false;
         }
         final FetchResponse f = (FetchResponse) response;
         /*
@@ -134,9 +134,10 @@ public final class SeqNumIMAPCommand extends AbstractIMAPCommand<int[]> {
         final long correspondingUID = uids[fetchRespIndex++];
         if (correspondingUID != currentUID) {
             LOG.warn("IMAPUtils.getSequenceNumbers(): UID mismatch");
-            return;
+            return false;
         }
         sia.append(f.getNumber());
+        return true;
     }
 
 }
