@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -56,7 +56,7 @@ import com.openexchange.mail.mime.MIMESessionPropertyNames;
 
 /**
  * {@link IMAPSessionProperties} - Default properties for an IMAP session established via <code>JavaMail</code> API
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class IMAPSessionProperties {
@@ -72,7 +72,7 @@ public final class IMAPSessionProperties {
 
     /**
      * Creates a <b>cloned</b> version of default IMAP session properties
-     * 
+     *
      * @return a cloned version of default IMAP session properties
      */
     public static Properties getDefaultSessionProperties() {
@@ -163,6 +163,10 @@ public final class IMAPSessionProperties {
          * Partial fetch size in bytes. Defaults to 16K.
          */
         properties.put("mail.imap.fetchsize", "51200");
+        /*
+         * Deny NTLM authentication
+         */
+        properties.put("mail.imap.auth.ntlm.disable", "true");
         /*
          * Apply configured JavaMail properties from file
          */
