@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -82,16 +82,27 @@ import com.openexchange.user.UserService;
  * </ul>
  * <p>
  * The complete implementation should be able to handle an ACL like this one:
- * 
+ *
  * <pre>
  * owner aceilrstwx anyone lr user=john w -user=mary r administrators aceilrstwx
  * </pre>
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public class DovecotEntity2ACL extends Entity2ACL {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(DovecotEntity2ACL.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(DovecotEntity2ACL.class));
+
+    private static final DovecotEntity2ACL INSTANCE = new DovecotEntity2ACL();
+
+    /**
+     * Gets the instance.
+     *
+     * @return The instance
+     */
+    public static DovecotEntity2ACL getInstance() {
+        return INSTANCE;
+    }
 
     private static final String ALIAS_OWNER = "owner";
 
@@ -104,8 +115,8 @@ public class DovecotEntity2ACL extends Entity2ACL {
             return null;
         }
         final String quotedDelim = Pattern.quote(String.valueOf(delim));
-        final String abstractPattern = new StringBuilder().append(SHARED_PREFIX).append(quotedDelim).append("([\\p{ASCII}&&[^").append(
-            quotedDelim).append("]]+)").append(quotedDelim).append("\\p{ASCII}+").toString();
+        final String abstractPattern = new StringBuilder().append(SHARED_PREFIX).append(quotedDelim).append("([\\p{L}&&[^").append(
+            quotedDelim).append("]]+)").append(quotedDelim).append("\\p{L}+").toString();
         final Matcher m = Pattern.compile(abstractPattern, Pattern.CASE_INSENSITIVE).matcher(sharedFolderName);
         if (m.matches()) {
             return m.group(1).replaceAll("\\s+", String.valueOf(delim));
@@ -118,7 +129,7 @@ public class DovecotEntity2ACL extends Entity2ACL {
     /**
      * Default constructor
      */
-    public DovecotEntity2ACL() {
+    private DovecotEntity2ACL() {
         super();
     }
 
