@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -57,13 +57,13 @@ import com.openexchange.mail.dataobjects.MailPart;
 
 /**
  * {@link DummyMailMessage} - A dummy mail message for thread-sort purpose.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 final class DummyMailMessage extends MailMessage {
 
     /**
-     * 
+     *
      */
     private static final long serialVersionUID = -541392246833470725L;
 
@@ -88,7 +88,7 @@ final class DummyMailMessage extends MailMessage {
 
     @Override
     public void setMailId(final String id) {
-        this.mailId = id;
+        mailId = id;
     }
 
     @Override
