@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,13 +49,14 @@
 
 package com.openexchange.imap.threadsort;
 
+import gnu.trove.list.TIntList;
+import gnu.trove.list.array.TIntArrayList;
 import java.util.ArrayList;
 import java.util.List;
 import javax.mail.MessagingException;
 import com.openexchange.imap.IMAPException;
 import com.openexchange.mail.dataobjects.MailMessage;
 import com.openexchange.mail.mime.ExtendedMimeMessage;
-import com.openexchange.tools.Collections.SmartIntArray;
 import com.sun.mail.iap.ProtocolException;
 import com.sun.mail.iap.Response;
 import com.sun.mail.imap.IMAPFolder;
@@ -64,12 +65,12 @@ import com.sun.mail.imap.protocol.IMAPResponse;
 
 /**
  * {@link ThreadSortUtil} - Utilities for thread-sort.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class ThreadSortUtil {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(ThreadSortUtil.class);
+    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(ThreadSortUtil.class));
 
     /**
      * Prevent instantiation
@@ -80,35 +81,53 @@ public final class ThreadSortUtil {
 
     /**
      * Creates a newly allocated array of <code>int</code> filled with message's sequence number.
-     * 
+     *
      * @param threadResponse The thread response string; e.g.<br>
      *            <code>&quot;&#042;&nbsp;THREAD&nbsp;(1&nbsp;(2)(3)(4)(5))(6)(7)(8)((9)(10)(11)(12)(13)(14)(15)(16)(17)(18)(19))&quot;</code>
      * @return A newly allocated array of <code>int</code> filled with message's sequence number
      */
-    public static int[] getSeqNumsFromThreadResponse(final String threadResponse) {
+    public static TIntList getSeqNumsFromThreadResponse(final String threadResponse) {
         final char[] chars = threadResponse.toCharArray();
-        final SmartIntArray sia = new SmartIntArray();
+        final TIntList list = new TIntArrayList(256);
         final StringBuilder sb = new StringBuilder(8);
         int i = 0;
         while (i < chars.length) {
             char c = chars[i++];
-            while (Character.isDigit(c)) {
+            if (isDigit(c)) {
                 sb.append(c);
-                c = chars[i++];
+                while (i < chars.length && isDigit((c = chars[i++]))) {
+                    sb.append(c);
+                }
             }
             if (sb.length() > 0) {
-                sia.append(Integer.parseInt(sb.toString()));
+                list.add(Integer.parseInt(sb.toString()));
                 sb.setLength(0);
             }
         }
-        return sia.toArray();
+        return list;
+    }
+
+    private static final char DIGIT_START = '\u0030';
+
+    private static final char DIGIT_END = '\u0039';
+
+    /**
+     * Determines if the specified character is a ISO-LATIN-1 digit.
+     * <p>
+     * '\u0030' through '\u0039', ISO-LATIN-1 digits ('0' through '9');
+     * 
+     * @param c The character to check for a digit
+     * @return <code>true</code> if character is a ISO-LATIN-1 digit; otherwise <code>false</code>
+     */
+    private static boolean isDigit(final char c) {
+        return c >= DIGIT_START && c <= DIGIT_END;
     }
 
     // private static final Pattern PATTERN_THREAD_RESP = Pattern.compile("[0-9]+");
 
     /**
      * Creates a newly allocated array of <code>javax.mail.Message</code> objects only filled with message's sequence number.
-     * 
+     *
      * @return An array of <code>javax.mail.Message</code> objects only filled with message's sequence number.
      */
     public static ExtendedMimeMessage[] getMessagesFromThreadResponse(final String folderFullname, final char separator, final String threadResponse) {
@@ -130,8 +149,8 @@ public final class ThreadSortUtil {
         return tmp.toArray(new ExtendedMimeMessage[tmp.size()]);
         /*-
          * Formerly:
-         * 
-        
+         *
+
         final Pattern PATTERN_THREAD_RESP = Pattern.compile("[0-9]+");
         final Matcher m = PATTERN_THREAD_RESP.matcher(threadResponse);
         if (m.find()) {
@@ -147,7 +166,7 @@ public final class ThreadSortUtil {
 
     /**
      * Parses specified thread-sort string.
-     * 
+     *
      * @return Parsed thread-sort string in a structured data type
      */
     public static List<ThreadSortNode> parseThreadResponse(final String threadResponse) throws IMAPException {
@@ -166,7 +185,7 @@ public final class ThreadSortUtil {
 
     /**
      * Executes THREAD command with given arguments.
-     * 
+     *
      * @param imapFolder The IMAP folder on which THREAD command shall be executed
      * @param sortRange The THREAD command argument specifying the sort range; e.g. <code>&quot;ALL&quot;</code> or
      *            <code>&quot;12,13,14,24&quot;</code>
@@ -216,7 +235,7 @@ public final class ThreadSortUtil {
 
     /**
      * Outputs specified structured list to given string builder.
-     * 
+     *
      * @param structuredList The structured list
      * @param sb The string builder to output to
      */
@@ -238,7 +257,7 @@ public final class ThreadSortUtil {
 
     /**
      * Converts specified structured list to a flat list.
-     * 
+     *
      * @param structuredList The structured list
      * @param flatList The flat list to fill
      */
@@ -255,7 +274,7 @@ public final class ThreadSortUtil {
 
     /**
      * Generates a structured list from specified mails.
-     * 
+     *
      * @param mails The mails with thread level applied
      * @return A structured list reflecting thread-order structure
      */
